## SATX [![Downloads](https://pepy.tech/badge/satx)](https://pepy.tech/project/satx)

The SATX its an automatic CNF compiler and interpreter integrated with Python.

## Installation
```python
pip install satx
```

Note: SATX is an experimental and under research extension of www.PEQNP.com work different, with support for negative numbers, modular arithmetics, and more...

<img
  src="https://cr-ss-service.azurewebsites.net/api/ScreenShot?widget=summary&username=maxtuno&badges=2&show-avatar=true&style=--header-bg-color:%23000;--border-radius:10px"/>
